@@ -6,6 +6,7 @@ from auditlog.models import LogEntry
 
 
 class LogEntryAdmin(admin.ModelAdmin, LogEntryAdminMixin):
+    list_select_related = ["content_type", "actor"]
     list_display = ["created", "resource_url", "action", "msg_short", "user_url"]
     search_fields = [
         "timestamp",
@@ -22,5 +23,9 @@ class LogEntryAdmin(admin.ModelAdmin, LogEntryAdminMixin):
         ("Changes", {"fields": ["action", "msg"]}),
     ]
 
+    def has_add_permission(self, request):
+        # As audit admin doesn't allow log creation from admin
+        return False
+
 
 admin.site.register(LogEntry, LogEntryAdmin)
