@@ -1,6 +1,7 @@
 import datetime
 import itertools
 import json
+import warnings
 from unittest import mock
 
 from dateutil.tz import gettz
@@ -600,6 +601,18 @@ class DateTimeFieldModelTest(TestCase):
     utc_plus_one = timezone.get_fixed_timezone(datetime.timedelta(hours=1))
     now = timezone.now()
 
+    def setUp(self):
+        super().setUp()
+        self._context = warnings.catch_warnings()
+        self._context.__enter__()
+        warnings.filterwarnings(
+            "ignore", message=".*naive datetime", category=RuntimeWarning
+        )
+
+    def tearDown(self):
+        self._context.__exit__()
+        super().tearDown()
+
     def test_model_with_same_time(self):
         timestamp = datetime.datetime(2017, 1, 10, 12, 0, tzinfo=timezone.utc)
         date = datetime.date(2017, 1, 10)
@@ -1260,12 +1273,25 @@ class DiffMsgTest(TestCase):
             changes=json.dumps(changes),
         )
 
-    def test_changes_msg__delete(self):
-        log_entry = self._create_log_entry(LogEntry.Action.DELETE, {})
+    def test_changes_msg_delete(self):
+        log_entry = self._create_log_entry(
+            LogEntry.Action.DELETE,
+            {"field one": ["value before deletion", None], "field two": [11, None]},
+        )
 
-        self.assertEqual(self.admin.msg(log_entry), "")
+        self.assertEqual(self.admin.msg_short(log_entry), "")
+        self.assertEqual(
+            self.admin.msg(log_entry),
+            (
+                "<table>"
+                "<tr><th>#</th><th>Field</th><th>From</th><th>To</th></tr>"
+                "<tr><td>1</td><td>field one</td><td>value before deletion</td><td>None</td></tr>"
+                "<tr><td>2</td><td>field two</td><td>11</td><td>None</td></tr>"
+                "</table>"
+            ),
+        )
 
-    def test_changes_msg__create(self):
+    def test_changes_msg_create(self):
         log_entry = self._create_log_entry(
             LogEntry.Action.CREATE,
             {
@@ -1274,6 +1300,9 @@ class DiffMsgTest(TestCase):
             },
         )
 
+        self.assertEqual(
+            self.admin.msg_short(log_entry), "2 changes: field two, field one"
+        )
         self.assertEqual(
             self.admin.msg(log_entry),
             (
@@ -1285,7 +1314,7 @@ class DiffMsgTest(TestCase):
             ),
         )
 
-    def test_changes_msg__update(self):
+    def test_changes_msg_update(self):
         log_entry = self._create_log_entry(
             LogEntry.Action.UPDATE,
             {
@@ -1294,6 +1323,9 @@ class DiffMsgTest(TestCase):
             },
         )
 
+        self.assertEqual(
+            self.admin.msg_short(log_entry), "2 changes: field two, field one"
+        )
         self.assertEqual(
             self.admin.msg(log_entry),
             (
@@ -1306,7 +1338,7 @@ class DiffMsgTest(TestCase):
             ),
         )
 
-    def test_changes_msg__m2m(self):
+    def test_changes_msg_m2m(self):
         log_entry = self._create_log_entry(
             LogEntry.Action.UPDATE,
             {  # mimicking the format used by log_m2m_changes
@@ -1318,6 +1350,7 @@ class DiffMsgTest(TestCase):
             },
         )
 
+        self.assertEqual(self.admin.msg_short(log_entry), "1 change: some_m2m_field")
         self.assertEqual(
             self.admin.msg(log_entry),
             (
